<?php
/*
Plugin Name: Gravity Forms Luminate Constituents Add-On
Plugin URI: https://cornershopcreative.com/product/gravity-forms-add-ons/
Description: Integrates Gravity Forms with Luminate CRM, allowing form submissions to automatically create/update Constituents, map submissions to surveys (targets Convio Constituents Only and surveys, NOT Alerts)
Version: 1.2.21
Author: Cornershop Creative
Author URI: https://cornershopcreative.com
Text Domain: gfluminate
*/

if ( ! function_exists( 'get_plugin_data' ) ) {
	require_once( ABSPATH . 'wp-admin/includes/plugin.php' );
}

$gravity_forms_luminate = get_plugin_data( __FILE__, true );
define( 'GF_LUMINATE_VERSION', $gravity_forms_luminate['Version'] );
// remove from global so we don't pollute global
unset( $gravity_forms_luminate );

add_action( 'gform_loaded', array( 'GF_Luminate_Bootstrap', 'load' ), 5 );

/**
 * Tells GravityForms to load up the Add-On
 */
class GF_Luminate_Bootstrap {

	public static function load() {

		if ( ! method_exists( 'GFForms', 'include_feed_addon_framework' ) ) {
			return;
		}

		if ( ! class_exists( '\WP_HTTP_Luminate' ) ) {
			require_once( __DIR__  . '/inc/class-wp-http-luminate.php' );
		}

		require_once( __DIR__  . '/inc/class-gf-luminate.php' );

		GFAddOn::register( 'GFLuminate' );
	}
}

function gf_luminate() {
	return GFLuminate::get_instance();
}

/**
 * Create a input mask for Luminate data
 *
 * Create a new input mask that makes sure that user inputs only contain certain characters before sending it off to Gravityforms
 *
 * @param array $masks current input masks
 * @return array Newly added input masks
 */
function gfluminate_gravityforms_add_input_masks( $masks ) {
	// usernames can only contain alphanumeric characters with "@,+,-,_,:,." signs with a minumum of 5 characters and a max of 60 characters
	$input_mask = '*';
	$fifty_five_more_characters = '';
	for ( $i = 0; $i < 55; $i++ ) {
		$fifty_five_more_characters .= $input_mask;
	}
	$masks['Luminate Username'] = '*?' . $fifty_five_more_characters;

	return $masks;
}

add_filter( 'gform_input_masks', 'gfluminate_gravityforms_add_input_masks' );
